#ifndef MAINOBJECT_H
#define MAINOBJECT_H

#include <QObject>
#include <stdio.h>
#include <QDir>
#include <QDebug>
#include <QString>
#include <QTcpSocket>
#include <QFileInfo>
#include <QJsonDocument>
#include <QStandardPaths>
#include <memory>


#ifndef Q_OS_ANDROID
#include <QtSerialPort/QtSerialPort>
#include <QtSerialPort/QSerialPortInfo>
#include <QCommandLineParser>
#endif

#include "actors/alarmtime.h"
#include "microcontroller.h"
#include "ui/mainwindow.h"
#include "sensors/speakersensor.h"
#include "sensors/sunsensor.h"
#include "sensors/ocupancysensor.h"
#include "sensors/sensor.h"
#include "items/itemstore.h"
#include "items/auxitem.h"
#include "items/rgbitem.h"
#include "items/poweritem.h"
#include "iomuliplexer.h"
#include "broadcast.h"

class MainObject : public QObject
{
	Q_OBJECT
public:

	//io
	const bool master;

	bool noSave = false;

	QIODevice * const masterIODevice = nullptr;
	IoMuliplexer ioMultiplexer;

	Microcontroller micro;
	BroadCast broadCast;

	const QString settingsPath;

	//sensors
	SunSensorSource     sunSensorSource;
	OcupancySensorSource ocupancySensor;

	//items
	ItemStore items;

	std::shared_ptr<PowerItem> powerItem;
	std::shared_ptr<RgbItem> rgbItem;
	std::shared_ptr<AuxItem> auxItem;

private:

	static QJsonObject getJsonObjectFromDisk(const QString& filePath = "", bool* error = nullptr);
	static bool storeJsonObjectToDisk(const QJsonObject& json, QString filePath = "");

public:
	explicit MainObject(QIODevice* ioDevice, const QString& settingsPathIn, const bool masterIn, QObject *parent = nullptr);
	~MainObject();

	void store(QJsonObject& json);

	void load(const QJsonObject& json);

signals:

public slots:

	void storeToDisk();
	void sendJson();
	void recivedJson(const QJsonObject json);

};

#endif // MAINOBJECT_H
